@@ -21,6 +21,11 @@ private Q_SLOTS:
     void testVolatileProperties();
     void testCuType();
     void testAlarm();
+    void testDateTimeSerialization_data();
+    void testDateTimeSerialization();
+    void testRDate();
+    void testDateTime_data();
+    void testDateTime();
 };
 
 #endif
